xf86-video-amdgpu: Branch 'master'

GitLab Mirror gitlab-mirror at kemper.freedesktop.org
Mon Feb 14 19:26:18 UTC 2022


 src/amdgpu_pixmap.c |    2 +-
 src/simple_list.h   |   10 +++++-----
 2 files changed, 6 insertions(+), 6 deletions(-)

New commits:
commit 8bc148f0c14f6a6df1c3643a774e00a00c7942c6
Author: Alan Coopersmith <alan.coopersmith at oracle.com>
Date:   Mon Jan 17 14:25:12 2022 -0800

    Fix spelling/wording issues
    
    Found by using:
        codespell --builtin clear,rare,usage,informal,code,names
    
    Signed-off-by: Alan Coopersmith <alan.coopersmith at oracle.com>

diff --git a/src/amdgpu_pixmap.c b/src/amdgpu_pixmap.c
index c5e80ad..18bdf4a 100644
--- a/src/amdgpu_pixmap.c
+++ b/src/amdgpu_pixmap.c
@@ -38,7 +38,7 @@ amdgpu_pixmap_create(ScreenPtr screen, int w, int h, int depth,	unsigned usage)
 	PixmapPtr pixmap;
 	AMDGPUInfoPtr info;
 
-	/* only DRI2 pixmap is suppported */
+	/* only DRI2 pixmap is supported */
 	if (!(usage & AMDGPU_CREATE_PIXMAP_DRI2))
 		return fbCreatePixmap(screen, w, h, depth, usage);
 
diff --git a/src/simple_list.h b/src/simple_list.h
index 94a8af4..d569cff 100644
--- a/src/simple_list.h
+++ b/src/simple_list.h
@@ -2,7 +2,7 @@
  * \file simple_list.h
  * Simple macros for type-safe, intrusive lists.
  *
  *  Intended to work with a list sentinal which is created as an empty
  *  list.  Insert & delete are O(1).
  *  
  * \author
@@ -107,12 +107,12 @@ do {						\
 /**
  * Make a empty list empty.
  *
- * \param sentinal list (sentinal element).
+ * \param sentinel list (sentinel element).
  */
-#define make_empty_list(sentinal)		\
+#define make_empty_list(sentinel)		\
 do {						\
-   (sentinal)->next = sentinal;			\
-   (sentinal)->prev = sentinal;			\
+   (sentinel)->next = sentinel;			\
+   (sentinel)->prev = sentinel;			\
 } while (0)
 
 /**
@@ -2,7 +2,7 @@
  * Simple macros for type-safe, intrusive lists.
  *
- *  Intended to work with a list sentinal which is created as an empty
+ *  Intended to work with a list sentinel which is created as an empty
  *  list.  Insert & delete are O(1).
  *  


More information about the xorg-commit mailing list